@@ -3,8 +3,11 @@ use std::io::{BufReader, Read};
 use std::path::Path;
 use std::str::FromStr;
 
+#[cfg(feature = "bzip2")]
 use bzip2::read::BzDecoder;
 use flate2::read::GzDecoder;
+#[cfg(feature = "xz")]
+use xz::read::XzDecoder;
 use zip::ZipArchive;
 
 use crate::{Error, Metadata};
@@ -24,7 +27,12 @@ pub enum DistributionType {
 enum SDistType {
     Zip,
     GzTar,
+    #[cfg(feature = "deprecated-formats")]
+    Tar,
+    #[cfg(feature = "bzip2")]
     BzTar,
+    #[cfg(feature = "xz")]
+    XzTar,
 }
 
 /// Python package distribution
@@ -52,7 +60,12 @@ impl FromStr for SDistType {
         let dist_type = match s {
             "zip" => SDistType::Zip,
             "gz" => SDistType::GzTar,
+            #[cfg(feature = "deprecated-formats")]
+            "tar" => SDistType::Tar,
+            #[cfg(feature = "bzip2")]
             "bz2" => SDistType::BzTar,
+            #[cfg(feature = "xz")]
+            "xz" => SDistType::XzTar,
             _ => return Err(Error::UnknownDistributionType),
         };
         Ok(dist_type)
@@ -65,9 +78,15 @@ impl Distribution {
         let path = path.as_ref();
         if let Some(ext) = path.extension().and_then(|ext| ext.to_str()) {
             let dist_type = match ext {
-                "zip" | "gz" | "bz2" => DistributionType::SDist,
+                "zip" | "gz" => DistributionType::SDist,
                 "egg" => DistributionType::Egg,
                 "whl" => DistributionType::Wheel,
+                #[cfg(feature = "deprecated-formats")]
+                "tar" => DistributionType::SDist,
+                #[cfg(feature = "bzip2")]
+                "bz2" => DistributionType::SDist,
+                #[cfg(feature = "xz")]
+                "xz" => DistributionType::SDist,
                 _ => return Err(Error::UnknownDistributionType),
             };
             let (metadata, python_version) = match dist_type {
@@ -136,9 +155,16 @@ impl Distribution {
             SDistType::GzTar => {
                 Self::parse_tar(GzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
             }
+            #[cfg(feature = "deprecated-formats")]
+            SDistType::Tar => Self::parse_tar(BufReader::new(fs_err::File::open(path)?)),
+            #[cfg(feature = "bzip2")]
             SDistType::BzTar => {
                 Self::parse_tar(BzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
             }
+            #[cfg(feature = "xz")]
+            SDistType::XzTar => {
+                Self::parse_tar(XzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
+            }
         }
     }
 
